@@ -58,7 +58,7 @@ KNotesSummaryWidget::KNotesSummaryWidget(KontactInterface::Plugin *plugin, QWidg
     mDefaultPixmap = KIconLoader::global()->loadIcon(QStringLiteral("knotes"), KIconLoader::Desktop);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->setSpacing(3);
-    mainLayout->setMargin(3);
+    mainLayout->setContentsMargins(3, 3, 3, 3);
 
     QWidget *header = createHeader(this, QStringLiteral("view-pim-notes"), i18n("Popup Notes"));
     mainLayout->addWidget(header);
@@ -189,10 +189,10 @@ void KNotesSummaryWidget::createNote(const Akonadi::Item &item, int counter)
     urlLabel->installEventFilter(this);
     urlLabel->setAlignment(Qt::AlignLeft);
     urlLabel->setWordWrap(true);
-    connect(urlLabel, QOverload<const QString &>::of(&KUrlLabel::leftClickedUrl),
+    connect(urlLabel, qOverload<const QString &>(&KUrlLabel::leftClickedUrl),
             this, &KNotesSummaryWidget::slotSelectNote);
 
-    connect(urlLabel, QOverload<const QString &>::of(&KUrlLabel::rightClickedUrl),
+    connect(urlLabel, qOverload<const QString &>(&KUrlLabel::rightClickedUrl),
             this, &KNotesSummaryWidget::slotPopupMenu);
 
     mLayout->addWidget(urlLabel, counter, 1);
